@@ -3,7 +3,7 @@
  * pgpool: a language independent connection pool server for PostgreSQL
  * written by Tatsuo Ishii
  *
- * Copyright (c) 2003-2019	PgPool Global Development Group
+ * Copyright (c) 2003-2020	PgPool Global Development Group
  *
  * Permission to use, copy, modify, and distribute this software and
  * its documentation for any purpose and without fee is hereby
@@ -985,7 +985,7 @@ authenticate_frontend_clear_text(POOL_CONNECTION * frontend)
 				(errmsg("clear text authentication failed"),
 				 errdetail("password does not match")));
 	}
-	ereport(LOG,
+	ereport(DEBUG1,
 			(errmsg("clear text authentication successful with frontend")));
 
 	if (frontend->passwordMapping->pgpoolUser.passwordType == PASSWORD_TYPE_AES)
@@ -1086,7 +1086,7 @@ do_clear_text_password(POOL_CONNECTION * backend, POOL_CONNECTION * frontend, in
 	kind = send_password_packet(backend, protoMajor, pwd);
 
 	/* if authenticated, save info */
-	if (!reauth && kind == AUTH_REQ_OK)
+	if (kind == AUTH_REQ_OK)
 	{
 		if (IS_MASTER_NODE_ID(backend->db_node_id))
 		{
@@ -1229,7 +1229,7 @@ do_crypt(POOL_CONNECTION * backend, POOL_CONNECTION * frontend, int reauth, int
 	pool_read(backend, &kind, sizeof(kind));
 
 	/* if authenticated, save info */
-	if (!reauth && kind == 0)
+	if (kind == 0)
 	{
 		int			msglen;
 
@@ -1589,7 +1589,7 @@ authenticate_frontend_md5(POOL_CONNECTION * backend, POOL_CONNECTION * frontend,
 				(errmsg("md5 authentication failed"),
 				 errdetail("password does not match")));
 	}
-	ereport(LOG,
+	ereport(DEBUG1,
 			(errmsg("md5 authentication successful with frontend")));
 
 	frontend->frontend_authenticated = true;
@@ -2369,7 +2369,7 @@ do_SCRAM(POOL_CONNECTION * frontend, POOL_CONNECTION * backend, int protoMajor,
 				ereport(ERROR,
 						(errmsg("invalid authentication request from server: unknown auth kind %d", auth_kind)));
 		}
-		/* Read next packend */
+		/* Read next backend */
 		pool_read(backend, &kind, sizeof(kind));
 		pool_read(backend, &len, sizeof(len));
 		if (kind != 'R')
@@ -2377,7 +2377,7 @@ do_SCRAM(POOL_CONNECTION * frontend, POOL_CONNECTION * backend, int protoMajor,
 					(errmsg("backend authentication failed"),
 					 errdetail("backend response with kind \'%c\' when expecting \'R\'", kind)));
 		message_length = ntohl(len);
-		if (len <= 8)
+		if (message_length < 8)
 			ereport(ERROR,
 					(errmsg("backend authentication failed"),
 					 errdetail("backend response with no data ")));
