@@ -242,7 +242,10 @@ do_child(int *fds)
 		MemoryContextSwitchTo(ProcessLoopContext);
 
 		if (accepted)
+		{
+			accepted = 0;
 			connection_count_down();
+		}
 
 		backend_cleanup(&child_frontend, backend, frontend_invalid);
 
@@ -642,6 +645,10 @@ read_startup_packet(POOL_CONNECTION * cp)
 							(errmsg("reading startup packet"),
 							 errdetail("application_name: %s", p)));
 				}
+				else
+				{
+					p += (strlen(p) + 1);
+				}
 
 				p += (strlen(p) + 1);
 			}
